#!/bin/bash
#
# ntpman.sh  -- Create man pages for ntp
#

VERSION=$1
SRCDIR=/usr/local/src/ntp
HTMLDIR=${SRCDIR}/ntp-${VERSION}/html
DISTFILE=/usr/portage/distfiles/ntp-${VERSION}.tar.gz
MANDIR=man

if [[ -z ${VERSION} ]] ; then
	echo "Usage: $0 <version>"
	exit 1
fi

if [[ ! -d ${HTMLDIR} ]] ; then
	if [[ -f ${DISTFILE} ]] ; then
		tar zxf ${DISTFILE} -C ${SRCDIR} || exit 1
	else
		echo "ERROR: $HTMLDIR / $DISTFILE does not exist"
		exit 1
	fi
fi

# Process a single HTML file
processfile() {
    HTMLFILE=$1
    MANFILE=$2
    echo -n "Processing $HTMLFILE ..."
	sed -e "s:<csobj.*<:csobj>/:" $HTMLDIR/$HTMLFILE > .$HTMLFILE
	xsltproc --html --stringparam version $VERSION ntp.xsl .$HTMLFILE > $MANDIR/$MANFILE || exit 1
	rm -f .$HTMLFILE
    echo "Done."
}

# Print information
echo "Generates ntp man files from HTML documentation. Using:"
echo "VERSION:   $VERSION"
echo "HTMLDIR:   $HTMLDIR"
echo "MANDIR:    $MANDIR"
echo "Press enter to continue, or Ctrl-C to cancel."
read

# Apply patch if still needed
(
cd $HTMLDIR
patch -p2 --dry-run < ../../ntpdc.html.patch -sf || exit 0
patch -p2 < ../../ntpdc.html.patch
)

# Process HTML files
rm -rf ${MANDIR}
mkdir ${MANDIR}
for f in ntp{date,dc,d,q,time,trace,dsim} keygen tickadj ; do
	processfile ${f}.html ${f}.8
done
echo

cp -vi /usr/local/src/freebsd/src/usr.sbin/ntp/doc/*.5 man/
cp -vi genmans.sh ntp.xsl man/

tar -jcf ntp-${VERSION}-manpages.tar.bz2 ${MANDIR}
du -b ntp-${VERSION}-manpages.tar.bz2
